# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ommx/v1/linear.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14ommx/v1/linear.proto\x12\x07ommx.v1\"\x8a\x01\n\x06Linear\x12*\n\x05terms\x18\x01 \x03(\x0b\x32\x14.ommx.v1.Linear.TermR\x05terms\x12\x1a\n\x08\x63onstant\x18\x02 \x01(\x01R\x08\x63onstant\x1a\x38\n\x04Term\x12\x0e\n\x02id\x18\x01 \x01(\x04R\x02id\x12 \n\x0b\x63oefficient\x18\x02 \x01(\x01R\x0b\x63oefficientBW\n\x0b\x63om.ommx.v1B\x0bLinearProtoP\x01\xa2\x02\x03OXX\xaa\x02\x07Ommx.V1\xca\x02\x07Ommx\\V1\xe2\x02\x13Ommx\\V1\\GPBMetadata\xea\x02\x08Ommx::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ommx.v1.linear_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013com.ommx.v1B\013LinearProtoP\001\242\002\003OXX\252\002\007Ommx.V1\312\002\007Ommx\\V1\342\002\023Ommx\\V1\\GPBMetadata\352\002\010Ommx::V1'
  _globals['_LINEAR']._serialized_start=34
  _globals['_LINEAR']._serialized_end=172
  _globals['_LINEAR_TERM']._serialized_start=116
  _globals['_LINEAR_TERM']._serialized_end=172
# @@protoc_insertion_point(module_scope)
