# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ommx/v1/function.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ommx.v1 import linear_pb2 as ommx_dot_v1_dot_linear__pb2
from ommx.v1 import polynomial_pb2 as ommx_dot_v1_dot_polynomial__pb2
from ommx.v1 import quadratic_pb2 as ommx_dot_v1_dot_quadratic__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16ommx/v1/function.proto\x12\x07ommx.v1\x1a\x14ommx/v1/linear.proto\x1a\x18ommx/v1/polynomial.proto\x1a\x17ommx/v1/quadratic.proto\"\xca\x01\n\x08\x46unction\x12\x1c\n\x08\x63onstant\x18\x01 \x01(\x01H\x00R\x08\x63onstant\x12)\n\x06linear\x18\x02 \x01(\x0b\x32\x0f.ommx.v1.LinearH\x00R\x06linear\x12\x32\n\tquadratic\x18\x03 \x01(\x0b\x32\x12.ommx.v1.QuadraticH\x00R\tquadratic\x12\x35\n\npolynomial\x18\x04 \x01(\x0b\x32\x13.ommx.v1.PolynomialH\x00R\npolynomialB\n\n\x08\x66unctionBY\n\x0b\x63om.ommx.v1B\rFunctionProtoP\x01\xa2\x02\x03OXX\xaa\x02\x07Ommx.V1\xca\x02\x07Ommx\\V1\xe2\x02\x13Ommx\\V1\\GPBMetadata\xea\x02\x08Ommx::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ommx.v1.function_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013com.ommx.v1B\rFunctionProtoP\001\242\002\003OXX\252\002\007Ommx.V1\312\002\007Ommx\\V1\342\002\023Ommx\\V1\\GPBMetadata\352\002\010Ommx::V1'
  _globals['_FUNCTION']._serialized_start=109
  _globals['_FUNCTION']._serialized_end=311
# @@protoc_insertion_point(module_scope)
