# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ommx/v1/sparse_matrix.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bommx/v1/sparse_matrix.proto\x12\x07ommx.v1\"\x90\x01\n\x0cSparseMatrix\x12\x19\n\x08num_rows\x18\x01 \x01(\x04R\x07numRows\x12\x1f\n\x0bnum_columns\x18\x02 \x01(\x04R\nnumColumns\x12\x12\n\x04rows\x18\x03 \x03(\x04R\x04rows\x12\x18\n\x07\x63olumns\x18\x04 \x03(\x04R\x07\x63olumns\x12\x16\n\x06values\x18\x05 \x03(\x01R\x06valuesB]\n\x0b\x63om.ommx.v1B\x11SparseMatrixProtoP\x01\xa2\x02\x03OXX\xaa\x02\x07Ommx.V1\xca\x02\x07Ommx\\V1\xe2\x02\x13Ommx\\V1\\GPBMetadata\xea\x02\x08Ommx::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ommx.v1.sparse_matrix_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013com.ommx.v1B\021SparseMatrixProtoP\001\242\002\003OXX\252\002\007Ommx.V1\312\002\007Ommx\\V1\342\002\023Ommx\\V1\\GPBMetadata\352\002\010Ommx::V1'
  _globals['_SPARSEMATRIX']._serialized_start=41
  _globals['_SPARSEMATRIX']._serialized_end=185
# @@protoc_insertion_point(module_scope)
